/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License;
 * you may not use this file except in compliance with the Elastic License.
 */
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License;
 * you may not use this file except in compliance with the Elastic License.
 */

import React, { useEffect, FC } from 'react';
import { i18n } from '@kbn/i18n';

import { timefilter } from 'ui/timefilter';

import { MlRoute, PageLoader, PageProps } from '../../router';
import { useResolver } from '../../use_resolver';

import { checkFullLicense } from '../../../license/check_license';
import { checkGetJobsPrivilege, checkPermission } from '../../../privilege/check_privilege';
import { checkMlNodesAvailable } from '../../../ml_nodes_check/check_ml_nodes';
import { NewCalendar } from '../../../settings/calendars';
import { SETTINGS, ML_BREADCRUMB } from '../../breadcrumbs';

enum MODE {
  NEW,
  EDIT,
}

interface NewCalendarPageProps extends PageProps {
  mode: MODE;
}

const newBreadcrumbs = [
  ML_BREADCRUMB,
  SETTINGS,
  {
    text: i18n.translate('xpack.ml.settings.breadcrumbs.calendarManagement.createLabel', {
      defaultMessage: 'Create',
    }),
    href: '#/settings/calendars_list/new_calendar',
  },
];

const editBreadcrumbs = [
  ML_BREADCRUMB,
  SETTINGS,
  {
    text: i18n.translate('xpack.ml.settings.breadcrumbs.calendarManagement.editLabel', {
      defaultMessage: 'Edit',
    }),
    href: '#/settings/calendars_list/edit_calendar',
  },
];

export const newCalendarRoute: MlRoute = {
  path: '/settings/calendars_list/new_calendar',
  render: (props, config, deps) => (
    <PageWrapper config={config} {...props} deps={deps} mode={MODE.NEW} />
  ),
  breadcrumbs: newBreadcrumbs,
};

export const editCalendarRoute: MlRoute = {
  path: '/settings/calendars_list/edit_calendar/:calendarId',
  render: (props, config, deps) => (
    <PageWrapper config={config} {...props} deps={deps} mode={MODE.EDIT} />
  ),
  breadcrumbs: editBreadcrumbs,
};

const PageWrapper: FC<NewCalendarPageProps> = ({ location, config, mode }) => {
  let calendarId: string | undefined;
  if (mode === MODE.EDIT) {
    const pathMatch: string[] | null = location.pathname.match(/.+\/(.+)$/);
    calendarId = pathMatch && pathMatch.length > 1 ? pathMatch[1] : undefined;
  }

  const { context } = useResolver(undefined, undefined, config, {
    checkFullLicense,
    checkGetJobsPrivilege,
    checkMlNodesAvailable,
  });

  useEffect(() => {
    timefilter.disableTimeRangeSelector();
    timefilter.disableAutoRefreshSelector();
  }, []);

  const canCreateCalendar = checkPermission('canCreateCalendar');
  const canDeleteCalendar = checkPermission('canDeleteCalendar');

  return (
    <PageLoader context={context}>
      <NewCalendar {...{ calendarId, canCreateCalendar, canDeleteCalendar }} />
    </PageLoader>
  );
};
