/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License;
 * you may not use this file except in compliance with the Elastic License.
 */

import { EuiPanel, EuiToolTip } from '@elastic/eui';
import React from 'react';
import styled from 'styled-components';

import { WithCopyToClipboard } from '../../../lib/clipboard/with_copy_to_clipboard';
import { Markdown } from '../../markdown';
import { WithHoverActions } from '../../with_hover_actions';
import * as i18n from '../translations';

const BodyContainer = styled(EuiPanel)`
  border: none;
`;

BodyContainer.displayName = 'BodyContainer';

const HoverActionsContainer = styled(EuiPanel)`
  align-items: center;
  display: flex;
  flex-direction: row;
  height: 25px;
  justify-content: center;
  left: 5px;
  position: absolute;
  top: -5px;
  width: 30px;
`;

HoverActionsContainer.displayName = 'HoverActionsContainer';

export const NoteCardBody = React.memo<{ rawNote: string }>(({ rawNote }) => (
  <BodyContainer data-test-subj="note-card-body" hasShadow={false} paddingSize="s">
    <WithHoverActions
      hoverContent={
        <HoverActionsContainer data-test-subj="hover-actions-container">
          <EuiToolTip content={i18n.COPY_TO_CLIPBOARD}>
            <WithCopyToClipboard text={rawNote} titleSummary={i18n.NOTE.toLowerCase()} />
          </EuiToolTip>
        </HoverActionsContainer>
      }
      render={() => <Markdown raw={rawNote} />}
    />
  </BodyContainer>
));

NoteCardBody.displayName = 'NoteCardBody';
